summaryrefslogtreecommitdiff
path: root/framework/Web
diff options
context:
space:
mode:
authorxue <>2006-03-03 13:04:52 +0000
committerxue <>2006-03-03 13:04:52 +0000
commitde70d1bbc0bb30bb308e898103f2c9729e4a0e8e (patch)
tree3626ac127f1c11365ebad1e2b9940bdb8dcb07a8 /framework/Web
parent65fd83336668ecd8ad2295c8d1e2055d533c650f (diff)
Changed TIframe to TInlineFrame.
Diffstat (limited to 'framework/Web')
-rw-r--r--framework/Web/UI/WebControls/TInlineFrame.php (renamed from framework/Web/UI/WebControls/TIframe.php)8
1 files changed, 4 insertions, 4 deletions
diff --git a/framework/Web/UI/WebControls/TIframe.php b/framework/Web/UI/WebControls/TInlineFrame.php
index e6a919ba..0daee2d3 100644
--- a/framework/Web/UI/WebControls/TIframe.php
+++ b/framework/Web/UI/WebControls/TInlineFrame.php
@@ -1,6 +1,6 @@
<?php
/**
- * TIframe class file.
+ * TInlineFrame class file.
*
* @author Jason Ragsdale <jrags@jasrags.net>
* @author Harry Pottash <hpottash@gmail.com>
@@ -12,9 +12,9 @@
*/
/**
- * TIframe class
+ * TInlineFrame class
*
* TIframe displays an inline frame (iframe) on a Web page.
* The location of the frame content is specified by {@link setFrameUrl FrameUrl}.
* The frame's alignment is specified by {@link setAlign Align}.
* The {@link setMarginWidth MarginWidth} and {@link setMarginHeight MarginHeight}
@@ -31,7 +31,7 @@
* @package System.Web.UI.WebControls
* @since 3.0
*/
-class TIframe extends TWebControl
+class TInlineFrame extends TWebControl
{
/**
* @return string tag name of the iframe.
@@ -12,9 +12,9 @@
*
- * TIframe displays an inline frame (iframe) on a Web page.
+ * TInlineFrame displays an inline frame (iframe) on a Web page.
* The location of the frame content is specified by {@link setFrameUrl FrameUrl}.
* The frame's alignment is specified by {@link setAlign Align}.